@@ -3,26 +3,35 @@
 import inspect
 import operator
 import re
-from collections import namedtuple
+from collections import ChainMap, namedtuple
 from functools import partial, wraps
-from typing import Any, Dict, Union, Optional, List, Callable, Iterable
+from itertools import chain
+from typing import (
+    Any,
+    Callable,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Type,
+    TypeVar,
+    Union,
+    no_type_check,
+)
 
 import pandas as pd
 
-from . import errors, constants
-
+from . import check_utils, constants, errors
+from . import strategies as st
 
 CheckResult = namedtuple(
-    "CheckResult", [
-        "check_passed",
-        "checked_object",
-        "failure_cases",
-    ])
+    "CheckResult",
+    ["check_output", "check_passed", "checked_object", "failure_cases"],
+)
 
 
 GroupbyObject = Union[
-    pd.core.groupby.SeriesGroupBy,
-    pd.core.groupby.DataFrameGroupBy
+    pd.core.groupby.SeriesGroupBy, pd.core.groupby.DataFrameGroupBy
 ]
 
 SeriesCheckObj = Union[pd.Series, Dict[str, pd.Series]]
@@ -33,16 +42,16 @@ def register_check_statistics(statistics_args):
     """Decorator to set statistics based on Check method."""
 
     def register_check_statistics_decorator(class_method):
-
         @wraps(class_method)
         def _wrapper(cls, *args, **kwargs):
             args = list(args)
-            arg_spec_args = inspect.getfullargspec(class_method).args[1:]
-            args_dict = {**dict(zip(arg_spec_args, args)), **kwargs}
+            arg_names = inspect.getfullargspec(class_method).args[1:]
+            if not arg_names:
+                arg_names = statistics_args
+            args_dict = {**dict(zip(arg_names, args)), **kwargs}
             check = class_method(cls, *args, **kwargs)
             check.statistics = {
                 stat: args_dict.get(stat) for stat in statistics_args
-                if args_dict.get(stat) is not None
             }
             check.statistics_args = statistics_args
             return check
@@ -52,21 +61,62 @@ def register_check_statistics(statistics_args):
     return register_check_statistics_decorator
 
 
-class _CheckBase():
+_T = TypeVar("_T", bound="_CheckBase")
+
+
+class _CheckMeta(type):  # pragma: no cover
+    """Check metaclass."""
+
+    REGISTERED_CUSTOM_CHECKS: Dict[str, Callable] = {}  # noqa
+
+    def __getattr__(cls, name: str) -> Any:
+        """Prevent attribute errors for registered checks."""
+        attr = ChainMap(cls.__dict__, cls.REGISTERED_CUSTOM_CHECKS).get(name)
+        if attr is None:
+            raise AttributeError(
+                f"'{cls}' object has no attribute '{name}'. "
+                "Make sure any custom checks have been registered "
+                "using the extensions api."
+            )
+        return attr
+
+    def __dir__(cls) -> Iterable[str]:
+        """Allow custom checks to show up as attributes when autocompleting."""
+        return chain(super().__dir__(), cls.REGISTERED_CUSTOM_CHECKS.keys())
+
+    # pylint: disable=line-too-long
+    # mypy has limited metaclass support so this doesn't pass typecheck
+    # see https://mypy.readthedocs.io/en/stable/metaclasses.html#gotchas-and-limitations-of-metaclass-support
+    # pylint: enable=line-too-long
+    @no_type_check
+    def __contains__(cls: Type[_T], item: Union[_T, str]) -> bool:
+        """Allow lookups for registered checks."""
+        if isinstance(item, cls):
+            name = item.name
+            return hasattr(cls, name)
+
+        # assume item is str
+        return hasattr(cls, item)
+
+
+class _CheckBase(metaclass=_CheckMeta):
     """Check base class."""
 
     def __init__(
-            self,
-            check_fn: Callable,
-            groups: Optional[Union[str, List[str]]] = None,
-            groupby: Optional[Union[str, List[str], Callable]] = None,
-            ignore_na: bool = True,
-            element_wise: bool = False,
-            name: str = None,
-            error: Optional[str] = None,
-            raise_warning: bool = False,
-            n_failure_cases: Union[int, None] = constants.N_FAILURE_CASES,
-            **check_kwargs
+        self,
+        check_fn: Union[
+            Callable[[pd.Series], Union[pd.Series, bool]],
+            Callable[[pd.DataFrame], Union[pd.DataFrame, pd.Series, bool]],
+        ],
+        groups: Optional[Union[str, List[str]]] = None,
+        groupby: Optional[Union[str, List[str], Callable]] = None,
+        ignore_na: bool = True,
+        element_wise: bool = False,
+        name: str = None,
+        error: Optional[str] = None,
+        raise_warning: bool = False,
+        n_failure_cases: Union[int, None] = constants.N_FAILURE_CASES,
+        **check_kwargs,
     ) -> None:
         """Apply a validation function to each element, Series, or DataFrame.
 
@@ -107,9 +157,9 @@ class _CheckBase():
 
             where the input is a dictionary mapping
             keys to subsets of the column/dataframe.
-        :param ignore_na: If True, drops null values on the checked series or
-            dataframe before passing into the ``check_fn``. For dataframes,
-            drops rows with any null value. *New in version 0.4.0*
+        :param ignore_na: If True, null values will be ignored when determining
+            if a check passed or failed. For dataframes, ignores rows with any
+            null value. *New in version 0.4.0*
         :param element_wise: Whether or not to apply validator in an
             element-wise fashion. If bool, assumes that all checks should be
             applied to the column element-wise. If list, should be the same
@@ -121,8 +171,8 @@ class _CheckBase():
             exception instead of raising a SchemaError for a specific check.
             This option should be used carefully in cases where a failing
             check is informational and shouldn't stop execution of the program.
-        :param n_failure_cases: report the top n failure cases. If None, then
-            report all failure cases.
+        :param n_failure_cases: report the first n unique failure cases. If
+            None, report all failure cases.
         :param check_kwargs: key-word arguments to pass into ``check_fn``
 
         :example:
@@ -153,9 +203,9 @@ class _CheckBase():
         >>>
         >>> schema = pa.DataFrameSchema(
         ...     columns={
-        ...         "measure_1": pa.Column(pa.Int, checks=measure_checks),
-        ...         "measure_2": pa.Column(pa.Int, checks=measure_checks),
-        ...         "group": pa.Column(pa.String),
+        ...         "measure_1": pa.Column(int, checks=measure_checks),
+        ...         "measure_2": pa.Column(int, checks=measure_checks),
+        ...         "group": pa.Column(str),
         ...     },
         ...     checks=check_dataframe
         ... )
@@ -179,12 +229,15 @@ class _CheckBase():
 
         if element_wise and groupby is not None:
             raise errors.SchemaInitError(
-                "Cannot use groupby when element_wise=True.")
+                "Cannot use groupby when element_wise=True."
+            )
         self._check_fn = check_fn
         self._check_kwargs = check_kwargs
         self.element_wise = element_wise
         self.error = error
-        self.name = name
+        self.name = name or getattr(
+            self._check_fn, "__name__", self._check_fn.__class__.__name__
+        )
         self.ignore_na = ignore_na
         self.raise_warning = raise_warning
         self.n_failure_cases = n_failure_cases
@@ -192,7 +245,8 @@ class _CheckBase():
         if groupby is None and groups is not None:
             raise ValueError(
                 "`groupby` argument needs to be provided when `groups` "
-                "argument is defined")
+                "argument is defined"
+            )
 
         if isinstance(groupby, str):
             groupby = [groupby]
@@ -214,12 +268,11 @@ class _CheckBase():
         """Set check statistics."""
         self._statistics = statistics
 
+    @staticmethod
     def _format_groupby_input(
-            self,
-            groupby_obj: GroupbyObject,
-            groups: Optional[List[str]],
+        groupby_obj: GroupbyObject,
+        groups: Optional[List[str]],
     ) -> Union[Dict[str, Union[pd.Series, pd.DataFrame]]]:
-        # pylint: disable=no-self-use
         """Format groupby object into dict of groups to Series or DataFrame.
 
         :param groupby_obj: a pandas groupby object.
@@ -232,17 +285,19 @@ class _CheckBase():
         invalid_groups = [g for g in groups if g not in group_keys]
         if invalid_groups:
             raise KeyError(
-                "groups %s provided in `groups` argument not a valid group "
-                "key. Valid group keys: %s" % (invalid_groups, group_keys))
+                f"groups {invalid_groups} provided in `groups` argument not a valid group "
+                f"key. Valid group keys: {group_keys}"
+            )
         return {
-            group_key: group for group_key, group in groupby_obj
+            group_key: group
+            for group_key, group in groupby_obj
             if group_key in groups
         }
 
     def _prepare_series_input(
-            self,
-            series: pd.Series,
-            dataframe_context: Optional[pd.DataFrame] = None
+        self,
+        df_or_series: Union[pd.Series, pd.DataFrame],
+        column: Optional[str] = None,
     ) -> SeriesCheckObj:
         """Prepare input for Column check.
 
@@ -254,22 +309,25 @@ class _CheckBase():
             to be used by `_check_fn` and `_vectorized_check`
 
         """
-        if dataframe_context is None or self.groupby is None:
-            return series
-        if isinstance(self.groupby, list):
-            groupby_obj = (
-                pd.concat([series, dataframe_context[self.groupby]], axis=1)
-                .groupby(self.groupby)[series.name]
+        if check_utils.is_field(df_or_series):
+            return df_or_series
+        elif self.groupby is None:
+            return df_or_series[column]
+        elif isinstance(self.groupby, list):
+            return self._format_groupby_input(
+                df_or_series.groupby(self.groupby)[column],
+                self.groups,
+            )
+        elif callable(self.groupby):
+            return self._format_groupby_input(
+                self.groupby(df_or_series)[column],
+                self.groups,
             )
-            return self._format_groupby_input(groupby_obj, self.groups)
-        if callable(self.groupby):
-            groupby_obj = self.groupby(
-                pd.concat([series, dataframe_context], axis=1))[series.name]
-            return self._format_groupby_input(groupby_obj, self.groups)
         raise TypeError("Type %s not recognized for `groupby` argument.")
 
     def _prepare_dataframe_input(
-            self, dataframe: pd.DataFrame) -> DataFrameCheckObj:
+        self, dataframe: pd.DataFrame
+    ) -> DataFrameCheckObj:
         """Prepare input for DataFrameSchema check.
 
         :param dataframe: dataframe to validate.
@@ -281,39 +339,10 @@ class _CheckBase():
         groupby_obj = dataframe.groupby(self.groupby)
         return self._format_groupby_input(groupby_obj, self.groups)
 
-    def _handle_na(
-            self,
-            df_or_series: Union[pd.DataFrame, pd.Series],
-            column: Optional[str] = None):
-        """Handle nan values before passing object to check function."""
-        if not self.ignore_na:
-            return df_or_series
-
-        drop_na_columns = []
-        if column is not None:
-            drop_na_columns.append(column)
-        if self.groupby is not None and isinstance(self.groupby, list):
-            # if groupby is specified as a list of columns, include them in
-            # the columns to consider when dropping records
-            for col in self.groupby:
-                # raise schema definition error if column is not in the
-                # validated dataframe
-                if isinstance(df_or_series, pd.DataFrame) and \
-                        col not in df_or_series:
-                    raise errors.SchemaDefinitionError(
-                        "`groupby` column '%s' not found" % col)
-            drop_na_columns.extend(self.groupby)
-
-        if drop_na_columns:
-            return df_or_series.loc[
-                df_or_series[drop_na_columns].dropna().index
-            ]
-        return df_or_series.dropna()
-
     def __call__(
-            self,
-            df_or_series: Union[pd.DataFrame, pd.Series],
-            column: Optional[str] = None,
+        self,
+        df_or_series: Union[pd.DataFrame, pd.Series],
+        column: Optional[str] = None,
     ) -> CheckResult:
         # pylint: disable=too-many-branches
         """Validate pandas DataFrame or Series.
@@ -321,106 +350,221 @@ class _CheckBase():
         :param df_or_series: pandas DataFrame of Series to validate.
         :param column: for dataframe checks, apply the check function to this
             column.
-        :returns: CheckResult tuple containing checked object,
-            check validation result, and failure cases from the checked object.
+        :returns: CheckResult tuple containing:
+
+            ``check_output``: boolean scalar, ``Series`` or ``DataFrame``
+            indicating which elements passed the check.
+
+            ``check_passed``: boolean scalar that indicating whether the check
+            passed overall.
+
+            ``checked_object``: the checked object itself. Depending on the
+            options provided to the ``Check``, this will be a pandas Series,
+            DataFrame, or if the ``groupby`` option is specified, a
+            ``Dict[str, Series]`` or ``Dict[str, DataFrame]`` where the keys
+            are distinct groups.
+
+            ``failure_cases``: subset of the check_object that failed.
         """
-        df_or_series = self._handle_na(df_or_series, column)
-
-        column_dataframe_context = None
-        if column is not None and isinstance(df_or_series, pd.DataFrame):
-            column_dataframe_context = df_or_series.drop(
-                column, axis="columns")
-            df_or_series = df_or_series[column].copy()
-
         # prepare check object
-        if isinstance(df_or_series, pd.Series):
-            check_obj = self._prepare_series_input(
-                df_or_series, column_dataframe_context)
-        elif isinstance(df_or_series, pd.DataFrame):
+        if check_utils.is_field(df_or_series) or (
+            column is not None and check_utils.is_table(df_or_series)
+        ):
+            check_obj = self._prepare_series_input(df_or_series, column)
+        elif check_utils.is_table(df_or_series):
             check_obj = self._prepare_dataframe_input(df_or_series)
         else:
             raise ValueError(
-                "object of type %s not supported. Must be a "
-                "Series, a dictionary of Series, or DataFrame" %
-                df_or_series)
+                f"object of type {type(df_or_series)} not supported. Must be "
+                "a Series, a dictionary of Series, or DataFrame"
+            )
 
         # apply check function to check object
         check_fn = partial(self._check_fn, **self._check_kwargs)
 
         if self.element_wise:
-            check_result = check_obj.apply(check_fn, axis=1) if \
-                isinstance(check_obj, pd.DataFrame) else \
-                check_obj.map(check_fn) if \
-                isinstance(check_obj, pd.Series) else check_fn(check_obj)
+            check_output = (
+                check_obj.apply(check_fn, axis=1)  # type: ignore
+                if check_utils.is_table(check_obj)
+                else check_obj.map(check_fn)  # type: ignore
+                if check_utils.is_field(check_obj)
+                else check_fn(check_obj)
+            )
         else:
             # vectorized check function case
-            check_result = check_fn(check_obj)
+            check_output = check_fn(check_obj)
 
         # failure cases only apply when the check function returns a boolean
         # series that matches the shape and index of the check_obj
-        if isinstance(check_obj, dict) or \
-                isinstance(check_result, bool) or \
-                not isinstance(check_result, (pd.Series, pd.DataFrame)) or \
-                check_obj.shape[0] != check_result.shape[0] or \
-                (check_obj.index != check_result.index).all():
+        if (
+            isinstance(check_obj, dict)
+            or isinstance(check_output, bool)
+            or not check_utils.is_supported_check_obj(check_output)
+            or check_obj.shape[0] != check_output.shape[0]
+            or (check_obj.index != check_output.index).all()
+        ):
             failure_cases = None
-        elif isinstance(check_result, pd.Series):
-            failure_cases = check_obj[~check_result]
-        elif isinstance(check_result, pd.DataFrame):
-            # check results consisting of a boolean dataframe should be
-            # reported at the most granular level.
-            failure_cases = (
-                check_obj.unstack()[~check_result.unstack()]
-                .rename("failure_case")
-                .rename_axis(["column", "index"])
-                .reset_index()
+        elif check_utils.is_field(check_output):
+            (
+                check_output,
+                failure_cases,
+            ) = check_utils.prepare_series_check_output(
+                check_obj,
+                check_output,
+                ignore_na=self.ignore_na,
+                n_failure_cases=self.n_failure_cases,
+            )
+        elif check_utils.is_table(check_output):
+            (
+                check_output,
+                failure_cases,
+            ) = check_utils.prepare_dataframe_check_output(
+                check_obj,
+                check_output,
+                df_orig=df_or_series,
+                ignore_na=self.ignore_na,
+                n_failure_cases=self.n_failure_cases,
             )
         else:
             raise TypeError(
-                "output type of check_fn not recognized: %s" %
-                type(check_result)
+                f"output type of check_fn not recognized: {type(check_output)}"
             )
 
-        # handle check_result return types
-        if isinstance(check_result, pd.Series):
-            check_passed = check_result.all()
-        elif isinstance(check_result, pd.DataFrame):
-            check_passed = check_result.all(axis=None)
-        else:
-            check_passed = check_result
-        return CheckResult(check_passed, check_obj, failure_cases)
-
-    def __eq__(self, other):
-        are_fn_objects_equal = \
-            self.__dict__["_check_fn"].__code__.co_code == \
-            other.__dict__["_check_fn"].__code__.co_code
-
-        are_all_other_check_attributes_equal = (
-            {i: self.__dict__[i] for i in self.__dict__ if i != '_check_fn'} ==
-            {i: other.__dict__[i] for i in other.__dict__ if i != '_check_fn'}
+        check_passed = (
+            check_output.all()
+            if check_utils.is_field(check_output)
+            else check_output.all(axis=None)
+            if check_utils.is_table(check_output)
+            else check_output
+        )
+        return CheckResult(
+            check_output, check_passed, check_obj, failure_cases
         )
 
-        return are_fn_objects_equal and are_all_other_check_attributes_equal
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, type(self)):
+            return NotImplemented
 
-    def __hash__(self):
-        return hash(self.__dict__["_check_fn"].__code__.co_code)
+        are_check_fn_objects_equal = (
+            self._get_check_fn_code() == other._get_check_fn_code()
+        )
 
-    def __repr__(self):
-        name = getattr(
-            self._check_fn, '__name__',
-            self._check_fn.__class__.__name__)
-        return "<Check %s: %s>" % (name, self.error) \
-            if self.error is not None else "<Check %s>" % name
+        try:
+            are_strategy_fn_objects_equal = all(
+                getattr(self.__dict__.get("strategy"), attr)
+                == getattr(other.__dict__.get("strategy"), attr)
+                for attr in ["func", "args", "keywords"]
+            )
+        except AttributeError:
+            are_strategy_fn_objects_equal = True
+
+        are_all_other_check_attributes_equal = {
+            k: v
+            for k, v in self.__dict__.items()
+            if k not in ["_check_fn", "strategy"]
+        } == {
+            k: v
+            for k, v in other.__dict__.items()
+            if k not in ["_check_fn", "strategy"]
+        }
+
+        return (
+            are_check_fn_objects_equal
+            and are_strategy_fn_objects_equal
+            and are_all_other_check_attributes_equal
+        )
+
+    def _get_check_fn_code(self):
+        check_fn = self.__dict__["_check_fn"]
+        try:
+            code = check_fn.__code__.co_code
+        except AttributeError:
+            # try accessing the functools.partial wrapper
+            code = check_fn.func.__code__.co_code
+
+        return code
+
+    def __hash__(self) -> int:
+        return hash(self._get_check_fn_code())
+
+    def __repr__(self) -> str:
+        return (
+            f"<Check {self.name}: {self.error}>"
+            if self.error is not None
+            else f"<Check {self.name}>"
+        )
 
 
 class Check(_CheckBase):
     """Check a pandas Series or DataFrame for certain properties."""
 
     @classmethod
+    @st.register_check_strategy(st.eq_strategy)
+    @register_check_statistics(["value"])
+    def equal_to(cls, value, **kwargs) -> "Check":
+        """Ensure all elements of a series equal a certain value.
+
+        *New in version 0.4.5*
+        Alias: ``eq``
+
+        :param value: All elements of a given :class:`pandas.Series` must have
+            this value
+        :param kwargs: key-word arguments passed into the `Check` initializer.
+
+        :returns: :class:`Check` object
+        """
+
+        def _equal(series: pd.Series) -> pd.Series:
+            """Comparison function for check"""
+            return series == value
+
+        return cls(
+            _equal,
+            name=cls.equal_to.__name__,
+            error=f"equal_to({value})",
+            **kwargs,
+        )
+
+    eq = equal_to
+
+    @classmethod
+    @st.register_check_strategy(st.ne_strategy)
+    @register_check_statistics(["value"])
+    def not_equal_to(cls, value, **kwargs) -> "Check":
+        """Ensure no elements of a series equals a certain value.
+
+        *New in version 0.4.5*
+        Alias: ``ne``
+
+        :param value: This value must not occur in the checked
+            :class:`pandas.Series`.
+        :param kwargs: key-word arguments passed into the `Check` initializer.
+
+        :returns: :class:`Check` object
+        """
+
+        def _not_equal(series: pd.Series) -> pd.Series:
+            """Comparison function for check"""
+            return series != value
+
+        return cls(
+            _not_equal,
+            name=cls.not_equal_to.__name__,
+            error=f"not_equal_to({value})",
+            **kwargs,
+        )
+
+    ne = not_equal_to
+
+    @classmethod
+    @st.register_check_strategy(st.gt_strategy)
     @register_check_statistics(["min_value"])
-    def greater_than(cls, min_value, **kwargs) -> 'Check':
+    def greater_than(cls, min_value, **kwargs) -> "Check":
         """Ensure values of a series are strictly greater than a minimum value.
 
+        *New in version 0.4.5*
+        Alias: ``gt``
+
         :param min_value: Lower bound to be exceeded. Must be a type comparable
             to the dtype of the :class:`pandas.Series` to be validated (e.g. a
             numerical type for float or int and a datetime for datetime).
@@ -438,15 +582,21 @@ class Check(_CheckBase):
         return cls(
             _greater_than,
             name=cls.greater_than.__name__,
-            error="greater_than(%s)" % min_value,
+            error=f"greater_than({min_value})",
             **kwargs,
         )
 
+    gt = greater_than
+
     @classmethod
+    @st.register_check_strategy(st.ge_strategy)
     @register_check_statistics(["min_value"])
-    def greater_than_or_equal_to(cls, min_value, **kwargs) -> 'Check':
+    def greater_than_or_equal_to(cls, min_value, **kwargs) -> "Check":
         """Ensure all values are greater or equal a certain value.
 
+        *New in version 0.4.5*
+        Alias: ``ge``
+
         :param min_value: Allowed minimum value for values of a series. Must be
             a type comparable to the dtype of the :class:`pandas.Series` to be
             validated.
@@ -464,15 +614,21 @@ class Check(_CheckBase):
         return cls(
             _greater_or_equal,
             name=cls.greater_than_or_equal_to.__name__,
-            error="greater_than_or_equal_to(%s)" % min_value,
+            error=f"greater_than_or_equal_to({min_value})",
             **kwargs,
         )
 
+    ge = greater_than_or_equal_to
+
     @classmethod
+    @st.register_check_strategy(st.lt_strategy)
     @register_check_statistics(["max_value"])
-    def less_than(cls, max_value, **kwargs) -> 'Check':
+    def less_than(cls, max_value, **kwargs) -> "Check":
         """Ensure values of a series are strictly below a maximum value.
 
+        *New in version 0.4.5*
+        Alias: ``lt``
+
         :param max_value: All elements of a series must be strictly smaller
             than this. Must be a type comparable to the dtype of the
             :class:`pandas.Series` to be validated.
@@ -490,14 +646,20 @@ class Check(_CheckBase):
         return cls(
             _less_than,
             name=cls.less_than.__name__,
-            error="less_than(%s)" % max_value,
+            error=f"less_than({max_value})",
             **kwargs,
         )
 
+    lt = less_than
+
     @classmethod
+    @st.register_check_strategy(st.le_strategy)
     @register_check_statistics(["max_value"])
-    def less_than_or_equal_to(cls, max_value, **kwargs) -> 'Check':
-        """Ensure no value of a series exceeds a certain value.
+    def less_than_or_equal_to(cls, max_value, **kwargs) -> "Check":
+        """Ensure values are less than or equal to a maximum value.
+
+        *New in version 0.4.5*
+        Alias: ``le``
 
         :param max_value: Upper bound not to be exceeded. Must be a type
             comparable to the dtype of the :class:`pandas.Series` to be
@@ -516,16 +678,20 @@ class Check(_CheckBase):
         return cls(
             _less_or_equal,
             name=cls.less_than_or_equal_to.__name__,
-            error="less_than_or_equal_to(%s)" % max_value,
-            **kwargs
+            error=f"less_than_or_equal_to({max_value})",
+            **kwargs,
         )
 
+    le = less_than_or_equal_to
+
     @classmethod
-    @register_check_statistics([
-        "min_value", "max_value", "include_min", "include_max"])
+    @st.register_check_strategy(st.in_range_strategy)
+    @register_check_statistics(
+        ["min_value", "max_value", "include_min", "include_max"]
+    )
     def in_range(
-            cls, min_value, max_value, include_min=True, include_max=True,
-            **kwargs) -> 'Check':
+        cls, min_value, max_value, include_min=True, include_max=True, **kwargs
+    ) -> "Check":
         """Ensure all values of a series are within an interval.
 
         :param min_value: Left / lower endpoint of the interval.
@@ -548,11 +714,13 @@ class Check(_CheckBase):
             raise ValueError("min_value must not be None")
         if max_value is None:
             raise ValueError("max_value must not be None")
-        if max_value < min_value or (min_value == max_value
-                                     and (not include_min or not include_max)):
+        if max_value < min_value or (
+            min_value == max_value and (not include_min or not include_max)
+        ):
             raise ValueError(
-                "The combination of min_value = %s and max_value = %s "
-                "defines an empty interval!" % (min_value, max_value))
+                f"The combination of min_value = {min_value} and max_value = {max_value} "
+                "defines an empty interval!"
+            )
         # Using functions from operator module to keep conditions out of the
         # closure
         left_op = operator.le if include_min else operator.lt
@@ -565,58 +733,14 @@ class Check(_CheckBase):
         return cls(
             _in_range,
             name=cls.in_range.__name__,
-            error="in_range(%s, %s)" % (min_value, max_value),
-            **kwargs,
-        )
-
-    @classmethod
-    @register_check_statistics(["value"])
-    def equal_to(cls, value, **kwargs) -> 'Check':
-        """Ensure all elements of a series equal a certain value.
-
-        :param value: All elements of a given :class:`pandas.Series` must have
-            this value
-        :param kwargs: key-word arguments passed into the `Check` initializer.
-
-        :returns: :class:`Check` object
-        """
-        def _equal(series: pd.Series) -> pd.Series:
-            """Comparison function for check"""
-            return series == value
-
-        return cls(
-            _equal,
-            name=cls.equal_to.__name__,
-            error="equal_to(%s)" % value,
-            **kwargs,
-        )
-
-    @classmethod
-    @register_check_statistics(["value"])
-    def not_equal_to(cls, value, **kwargs) -> 'Check':
-        """Ensure no elements of a series equals a certain value.
-
-        :param value: This value must not occur in the checked
-            :class:`pandas.Series`.
-        :param kwargs: key-word arguments passed into the `Check` initializer.
-
-        :returns: :class:`Check` object
-        """
-        def _not_equal(series: pd.Series) -> pd.Series:
-            """Comparison function for check"""
-            return series != value
-
-        return cls(
-            _not_equal,
-            name=cls.not_equal_to.__name__,
-            error="not_equal_to(%s)" % value,
+            error=f"in_range({min_value}, {max_value})",
             **kwargs,
         )
 
     @classmethod
+    @st.register_check_strategy(st.isin_strategy)
     @register_check_statistics(["allowed_values"])
-    def isin(
-            cls, allowed_values: Iterable, **kwargs) -> 'Check':
+    def isin(cls, allowed_values: Iterable, **kwargs) -> "Check":
         """Ensure only allowed values occur within a series.
 
         :param allowed_values: The set of allowed values. May be any iterable.
@@ -637,10 +761,10 @@ class Check(_CheckBase):
         # changed from outside.
         try:
             allowed_values = frozenset(allowed_values)
-        except TypeError:
+        except TypeError as exc:
             raise ValueError(
-                "Argument allowed_values must be iterable. Got %s" %
-                allowed_values)
+                f"Argument allowed_values must be iterable. Got {allowed_values}"
+            ) from exc
 
         def _isin(series: pd.Series) -> pd.Series:
             """Comparison function for check"""
@@ -649,14 +773,14 @@ class Check(_CheckBase):
         return cls(
             _isin,
             name=cls.isin.__name__,
-            error="isin(%s)" % set(allowed_values),
+            error=f"isin({set(allowed_values)})",
             **kwargs,
         )
 
     @classmethod
+    @st.register_check_strategy(st.notin_strategy)
     @register_check_statistics(["forbidden_values"])
-    def notin(
-            cls, forbidden_values: Iterable, **kwargs) -> 'Check':
+    def notin(cls, forbidden_values: Iterable, **kwargs) -> "Check":
         """Ensure some defined values don't occur within a series.
 
         :param forbidden_values: The set of values which should not occur. May
@@ -677,10 +801,10 @@ class Check(_CheckBase):
         # changed from outside.
         try:
             forbidden_values = frozenset(forbidden_values)
-        except TypeError:
+        except TypeError as exc:
             raise ValueError(
-                "Argument forbidden_values must be iterable. Got %s" %
-                forbidden_values)
+                f"Argument forbidden_values must be iterable. Got {forbidden_values}"
+            ) from exc
 
         def _notin(series: pd.Series) -> pd.Series:
             """Comparison function for check"""
@@ -689,13 +813,14 @@ class Check(_CheckBase):
         return cls(
             _notin,
             name=cls.notin.__name__,
-            error="notin(%s)" % set(forbidden_values),
+            error=f"notin({set(forbidden_values)})",
             **kwargs,
         )
 
     @classmethod
+    @st.register_check_strategy(st.str_matches_strategy)
     @register_check_statistics(["pattern"])
-    def str_matches(cls, pattern: str, **kwargs) -> 'Check':
+    def str_matches(cls, pattern: str, **kwargs) -> "Check":
         """Ensure that string values match a regular expression.
 
         :param pattern: Regular expression pattern to use for matching
@@ -708,10 +833,10 @@ class Check(_CheckBase):
         # By compiling the regex we get the benefit of an early argument check
         try:
             regex = re.compile(pattern)
-        except TypeError:
+        except TypeError as exc:
             raise ValueError(
-                'pattern="%s" cannot be compiled as regular expression' %
-                pattern)
+                f'pattern="{pattern}" cannot be compiled as regular expression'
+            ) from exc
 
         def _match(series: pd.Series) -> pd.Series:
             """
@@ -722,14 +847,14 @@ class Check(_CheckBase):
         return cls(
             _match,
             name=cls.str_matches.__name__,
-            error="str_matches(%s)" % regex,
+            error=f"str_matches({regex})",
             **kwargs,
         )
 
     @classmethod
+    @st.register_check_strategy(st.str_contains_strategy)
     @register_check_statistics(["pattern"])
-    def str_contains(
-            cls, pattern: str, **kwargs) -> 'Check':
+    def str_contains(cls, pattern: str, **kwargs) -> "Check":
         """Ensure that a pattern can be found within each row.
 
         :param pattern: Regular expression pattern to use for searching
@@ -742,10 +867,10 @@ class Check(_CheckBase):
         # By compiling the regex we get the benefit of an early argument check
         try:
             regex = re.compile(pattern)
-        except TypeError:
+        except TypeError as exc:
             raise ValueError(
-                'pattern="%s" cannot be compiled as regular expression' %
-                pattern)
+                f'pattern="{pattern}" cannot be compiled as regular expression'
+            ) from exc
 
         def _contains(series: pd.Series) -> pd.Series:
             """Check if a regex search is successful within each value"""
@@ -754,14 +879,14 @@ class Check(_CheckBase):
         return cls(
             _contains,
             name=cls.str_contains.__name__,
-            error="str_contains(%s)" % regex,
+            error=f"str_contains({regex})",
             **kwargs,
         )
 
     @classmethod
+    @st.register_check_strategy(st.str_startswith_strategy)
     @register_check_statistics(["string"])
-    def str_startswith(
-            cls, string: str, **kwargs) -> 'Check':
+    def str_startswith(cls, string: str, **kwargs) -> "Check":
         """Ensure that all values start with a certain string.
 
         :param string: String all values should start with
@@ -769,6 +894,7 @@ class Check(_CheckBase):
 
         :returns: :class:`Check` object
         """
+
         def _startswith(series: pd.Series) -> pd.Series:
             """Returns true only for strings starting with string"""
             return series.str.startswith(string, na=False)
@@ -776,13 +902,14 @@ class Check(_CheckBase):
         return cls(
             _startswith,
             name=cls.str_startswith.__name__,
-            error="str_startswith(%s)" % string,
+            error=f"str_startswith({string})",
             **kwargs,
         )
 
     @classmethod
+    @st.register_check_strategy(st.str_endswith_strategy)
     @register_check_statistics(["string"])
-    def str_endswith(cls, string: str, **kwargs) -> 'Check':
+    def str_endswith(cls, string: str, **kwargs) -> "Check":
         """Ensure that all values end with a certain string.
 
         :param string: String all values should end with
@@ -790,6 +917,7 @@ class Check(_CheckBase):
 
         :returns: :class:`Check` object
         """
+
         def _endswith(series: pd.Series) -> pd.Series:
             """Returns true only for strings ending with string"""
             return series.str.endswith(string, na=False)
@@ -797,17 +925,16 @@ class Check(_CheckBase):
         return cls(
             _endswith,
             name=cls.str_endswith.__name__,
-            error="str_endswith(%s)" % string,
+            error=f"str_endswith({string})",
             **kwargs,
         )
 
     @classmethod
+    @st.register_check_strategy(st.str_length_strategy)
     @register_check_statistics(["min_value", "max_value"])
     def str_length(
-            cls,
-            min_value: int = None,
-            max_value: int = None,
-            **kwargs) -> 'Check':
+        cls, min_value: int = None, max_value: int = None, **kwargs
+    ) -> "Check":
         """Ensure that the length of strings is within a specified range.
 
         :param min_value: Minimum length of strings (default: no minimum)
@@ -819,24 +946,31 @@ class Check(_CheckBase):
         if min_value is None and max_value is None:
             raise ValueError(
                 "At least a minimum or a maximum need to be specified. Got "
-                "None.")
+                "None."
+            )
         if max_value is None:
+
             def _str_length(series: pd.Series) -> pd.Series:
                 """Check for the minimum string length"""
                 return series.str.len() >= min_value
+
         elif min_value is None:
+
             def _str_length(series: pd.Series) -> pd.Series:
                 """Check for the maximum string length"""
                 return series.str.len() <= max_value
+
         else:
+
             def _str_length(series: pd.Series) -> pd.Series:
                 """Check for both, minimum and maximum string length"""
-                return (series.str.len() <= max_value) & \
-                    (series.str.len() >= min_value)
+                return (series.str.len() <= max_value) & (
+                    series.str.len() >= min_value
+                )
 
         return cls(
             _str_length,
             name=cls.str_length.__name__,
-            error="str_length(%s, %s)" % (min_value, max_value),
+            error=f"str_length({min_value}, {max_value})",
             **kwargs,
         )
